.. _all-salt.wheel:

==================================
Full list of builtin wheel modules
==================================

.. currentmodule:: salt.wheel

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    config
    error
    file_roots
    key
    minions
    pillar_roots
